import yamlenv
from .dotdict import Dotdict


class Hparam(Dotdict):

    def __init__(self, file):
        super(Dotdict, self).__init__()
        hp_dict = self._load_hparam(file)
        hp_dotdict = Dotdict(hp_dict)
        for k, v in hp_dotdict.items():
            setattr(self, k, v)

    def _load_hparam(self, filename: str) -> dict:
        stream = open(filename, 'r')
        docs = yamlenv.load_all(stream, Loader=yamlenv.SafeLoader)
        hparam_dict = dict()
        for doc in docs:
            for k, v in doc.items():
                hparam_dict[k] = v
        return hparam_dict

    __getattr__ = Dotdict.__getitem__
    __setattr__ = Dotdict.__setitem__
    __delattr__ = Dotdict.__delitem__



class Dotdict(dict):
    """
    dict with dot access
    """
    __getattr__ = dict.__getitem__
    __setattr__ = dict.__setitem__
    __delattr__ = dict.__delitem__

    def __init__(self, dct=None):
        dct = dict() if not dct else dct
        for key, value in dct.items():
            if hasattr(value, 'keys'):
                value = Dotdict(value)
            self[key] = value


from .utils import Hparam
from .utils import load, dump

"""
yamlparams

Python library for dot-access to parameters in yaml file
"""

__version__ = "1.0.5"
__author__ = 'Ilya Shamov'

if __name__ == "__main__":
    pass



from setuptools import setup

setup(
    name='yamlparams',
    version='1.0.5',
    description='Python library for dot-access to parameters in yaml file',
    url='https://github.com/ARQtty/yamlparams',
    author='Ilya Shamov',
    author_email='ShamovIA@yandex.ru',
    license='MIT',
    packages=['yamlparams'],
    install_requires=['yamlenv'],

    classifiers=[],
)
